pub struct WindowRelFunction {
pub function_reference: u32,
pub arguments: Vec<FunctionArgument>,
pub options: Vec<FunctionOption>,
pub output_type: Option<Type>,
pub phase: i32,
pub invocation: i32,
pub lower_bound: Option<Bound>,
pub upper_bound: Option<Bound>,
pub bounds_type: i32,
}Expand description
This message mirrors the WindowFunction message but removes the fields defining the partition,
sorts, and bounds, since those must be consistent across the various functions in this rel. Refer
to the WindowFunction message for a description of these fields.
Fields
function_reference: u32References a function_anchor defined in this plan.
arguments: Vec<FunctionArgument>options: Vec<FunctionOption>output_type: Option<Type>phase: i32invocation: i32lower_bound: Option<Bound>Defines the lower bound of the window frame.
Optional; defaults to the start of the partition.
See Expression.WindowFunction.Bound.
upper_bound: Option<Bound>Defines the upper bound of the window frame.
Optional; defaults to the end of the partition.
See Expression.WindowFunction.Bound.
bounds_type: i32Defines how this function’s window bounds are interpreted. Must be ROWS or RANGE when either bound is CurrentRow, Preceding, or Following.
For RANGE with a Preceding or Following bound, sorts on the enclosing
ConsistentPartitionWindowRel must contain exactly one ordering expression
and must not use SORT_DIRECTION_CLUSTERED or a custom comparison function.
Implementations
Sourceimpl WindowRelFunction
impl WindowRelFunction
Sourcepub fn phase(&self) -> AggregationPhase
pub fn phase(&self) -> AggregationPhase
Returns the enum value of phase, or the default if the field is set to an invalid enum value.
Sourcepub fn set_phase(&mut self, value: AggregationPhase)
pub fn set_phase(&mut self, value: AggregationPhase)
Sets phase to the provided enum value.
Sourcepub fn invocation(&self) -> AggregationInvocation
pub fn invocation(&self) -> AggregationInvocation
Returns the enum value of invocation, or the default if the field is set to an invalid enum value.
Sourcepub fn set_invocation(&mut self, value: AggregationInvocation)
pub fn set_invocation(&mut self, value: AggregationInvocation)
Sets invocation to the provided enum value.
Sourcepub fn bounds_type(&self) -> BoundsType
pub fn bounds_type(&self) -> BoundsType
Returns the enum value of bounds_type, or the default if the field is set to an invalid enum value.
Sourcepub fn set_bounds_type(&mut self, value: BoundsType)
pub fn set_bounds_type(&mut self, value: BoundsType)
Sets bounds_type to the provided enum value.